"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const utils_1 = require("./utils");
const constants = require("./constants");
/**
 * Make function which will manually update changed files
 */
function makeWatchRun(instance) {
    // Called Before starting compilation after watch
    const lastTimes = new Map();
    let startTime = 0;
    return (compiler, callback) => {
        if (null === instance.modifiedFiles) {
            instance.modifiedFiles = new Map();
        }
        // startTime = startTime || watching.startTime;
        const times = compiler.fileTimestamps;
        for (const [filePath, date] of times) {
            if (date > (lastTimes.get(filePath) || startTime)
                && filePath.match(constants.tsTsxJsJsxRegex)) {
                continue;
            }
            lastTimes.set(filePath, date);
            const nFilePath = path.normalize(filePath);
            const file = instance.files.get(nFilePath) || instance.otherFiles.get(nFilePath);
            if (file !== undefined) {
                file.text = utils_1.readFile(nFilePath) || '';
                file.version++;
                instance.version++;
                instance.modifiedFiles.set(nFilePath, file);
                if (instance.watchHost) {
                    instance.watchHost.invokeFileWatcher(nFilePath, instance.compiler.FileWatcherEventKind.Changed);
                }
            }
        }
        callback();
    };
}
exports.makeWatchRun = makeWatchRun;
